import * as defaultCompiler from 'vue/compiler-sfc';
import type { SFCAsyncStyleCompileOptions, SFCScriptCompileOptions, SFCTemplateCompileOptions } from 'vue/compiler-sfc';
export declare class File {
    filename: string;
    code: string;
    hidden: boolean;
    compiled: {
        js: string;
        css: string;
        ssr: string;
    };
    constructor(filename: string, code?: string, hidden?: boolean);
}
export interface StoreState {
    mainFile: string;
    files: Record<string, File>;
    activeFile: File;
    errors: (string | Error)[];
    vueRuntimeURL: string;
    vueServerRendererURL: string;
    resetFlip: boolean;
}
export interface SFCOptions {
    script?: Omit<SFCScriptCompileOptions, 'id'>;
    style?: SFCAsyncStyleCompileOptions;
    template?: SFCTemplateCompileOptions;
}
export interface Store {
    state: StoreState;
    options?: SFCOptions;
    compiler: typeof defaultCompiler;
    vueVersion?: string;
    init: () => void;
    getImportMap: () => any;
}
export interface StoreOptions {
    code?: string;
}
export declare class ReplStore implements Store {
    state: StoreState;
    compiler: typeof defaultCompiler;
    vueVersion?: string;
    options?: SFCOptions;
    private defaultVueRuntimeURL;
    private defaultVueServerRendererURL;
    private pendingCompiler;
    constructor({ code, }?: StoreOptions);
    init(): void;
    private forceSandboxReset;
    private initImportMap;
    getImportMap(): any;
    setImportMap(map: {
        imports: Record<string, string>;
        scopes?: Record<string, Record<string, string>>;
    }): void;
    setVueVersion(version: string): Promise<void>;
    resetVueVersion(): void;
}
